"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.clipping_plane import ClippingPlane
from bimdata_api_client.model.components_parent import ComponentsParent
from bimdata_api_client.model.line import Line
from bimdata_api_client.model.orthogonal_camera import OrthogonalCamera
from bimdata_api_client.model.perspective_camera import PerspectiveCamera
from bimdata_api_client.model.pin import Pin
from bimdata_api_client.model.snapshot import Snapshot
globals()['ClippingPlane'] = ClippingPlane
globals()['ComponentsParent'] = ComponentsParent
globals()['Line'] = Line
globals()['OrthogonalCamera'] = OrthogonalCamera
globals()['PerspectiveCamera'] = PerspectiveCamera
globals()['Pin'] = Pin
globals()['Snapshot'] = Snapshot
from bimdata_api_client.model.viewpoint import Viewpoint


class TestViewpoint(unittest.TestCase):
    """Viewpoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testViewpoint(self):
        """Test Viewpoint"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Viewpoint()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
