"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.raw_classification import RawClassification
from bimdata_api_client.model.raw_definition import RawDefinition
from bimdata_api_client.model.raw_element import RawElement
from bimdata_api_client.model.raw_layer import RawLayer
from bimdata_api_client.model.raw_material_list import RawMaterialList
from bimdata_api_client.model.raw_property_set import RawPropertySet
from bimdata_api_client.model.raw_system import RawSystem
from bimdata_api_client.model.raw_unit import RawUnit
globals()['RawClassification'] = RawClassification
globals()['RawDefinition'] = RawDefinition
globals()['RawElement'] = RawElement
globals()['RawLayer'] = RawLayer
globals()['RawMaterialList'] = RawMaterialList
globals()['RawPropertySet'] = RawPropertySet
globals()['RawSystem'] = RawSystem
globals()['RawUnit'] = RawUnit
from bimdata_api_client.model.raw_elements import RawElements


class TestRawElements(unittest.TestCase):
    """RawElements unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRawElements(self):
        """Test RawElements"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RawElements()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
