"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.raw_classification_request import RawClassificationRequest
from bimdata_api_client.model.raw_definition_request import RawDefinitionRequest
from bimdata_api_client.model.raw_element_request import RawElementRequest
from bimdata_api_client.model.raw_layer_request import RawLayerRequest
from bimdata_api_client.model.raw_material_list_request import RawMaterialListRequest
from bimdata_api_client.model.raw_property_set_request import RawPropertySetRequest
from bimdata_api_client.model.raw_system_request import RawSystemRequest
from bimdata_api_client.model.raw_unit_request import RawUnitRequest
globals()['RawClassificationRequest'] = RawClassificationRequest
globals()['RawDefinitionRequest'] = RawDefinitionRequest
globals()['RawElementRequest'] = RawElementRequest
globals()['RawLayerRequest'] = RawLayerRequest
globals()['RawMaterialListRequest'] = RawMaterialListRequest
globals()['RawPropertySetRequest'] = RawPropertySetRequest
globals()['RawSystemRequest'] = RawSystemRequest
globals()['RawUnitRequest'] = RawUnitRequest
from bimdata_api_client.model.raw_elements_request import RawElementsRequest


class TestRawElementsRequest(unittest.TestCase):
    """RawElementsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRawElementsRequest(self):
        """Test RawElementsRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RawElementsRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
