"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.marketplace_app_image import MarketplaceAppImage
from bimdata_api_client.model.public_organization import PublicOrganization
from bimdata_api_client.model.user import User
globals()['MarketplaceAppImage'] = MarketplaceAppImage
globals()['PublicOrganization'] = PublicOrganization
globals()['User'] = User
from bimdata_api_client.model.marketplace_app import MarketplaceApp


class TestMarketplaceApp(unittest.TestCase):
    """MarketplaceApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMarketplaceApp(self):
        """Test MarketplaceApp"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MarketplaceApp()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
